@@ -5,12 +5,12 @@
 #' because we often want to get predictions with one (or few) rows, where some
 #' factor levels are inevitably missing.
 #' @keywords internal
-complete_levels <- function(x, levels_character = NULL) {
+complete_levels <- function(x, character_levels = NULL) {
 
     checkmate::assert_data_frame(x)
 
     # fixest returned an empty list()
-    if (is.null(levels_character) || length(levels_character) == 0) {
+    if (is.null(character_levels) || length(character_levels) == 0) {
         return(data.frame())
     }
 
@@ -22,8 +22,8 @@ complete_levels <- function(x, levels_character = NULL) {
                 vault[[v]] <- factor(levels(x[[v]]), levels = levels(x[[v]]))
             }
         } else if (is.character(x[[v]])) {
-            if (v %in% names(levels_character)) {
-                vault[[v]] <- levels_character[[v]]
+            if (v %in% names(character_levels)) {
+                vault[[v]] <- character_levels[[v]]
             }
         }
     }
@@ -35,11 +35,15 @@ complete_levels <- function(x, levels_character = NULL) {
         for (v in names(vault)) {
             padding[[v]] <- NULL
         }
-        padding <- merge(padding, expand.grid(vault), all = TRUE)
+        fun <- data.table::CJ
+        gr <- do.call("fun", vault)
+        padding <- merge(padding, gr, all = TRUE)
         padding <- padding[, colnames(x)]
     } else {
         padding <- data.frame()
     }
 
+    padding$rowid <- -1 * padding$rowid
+
     return(padding)
 }
