@@ -8,7 +8,7 @@ find_categorical <- function(newdata = NULL, model = NULL) {
                       isTRUE(attr(newdata, "factor")))
         out_newdata <- colnames(newdata)[idx]
     }
-    # use terms to detect factor(), as.factor(), as.logical(), brms::mo(), survival::strata()
+    # use terms to detect factor(), as.factor(), as.logical(), brms::mo(), survival::strata(), fixest::i()
     if (!is.null(model)) {
         # terms: default
         te <- tryCatch(attr(stats::terms(model), "term.labels"), error = function(e) NULL)
@@ -19,10 +19,10 @@ find_categorical <- function(newdata = NULL, model = NULL) {
         }
 
         if (!is.null(te) && is.character(te)) {
-            te <- te[grepl("^as\\.factor|^factor\\(|^as.logical\\(|^mo\\(|^strata\\(", te)]
+            te <- te[grepl("^as\\.factor|^factor\\(|^as.logical\\(|^mo\\(|^strata\\(|^i\\(", te)]
             # some functions like strata() take arguments, but that is difficult to support
+            te <- gsub("^(^as\\.factor|^factor|^i|^as\\.logical|mo|strata)\\((.*)\\)", "\\2", te)
             te <- te[!grepl(",", te)]
-            te <- gsub("^(^as\\.factor|^factor|^as\\.logical|mo|strata)\\((.*)\\)", "\\2", te)
             out_model <- te
         }
     }
