@@ -41,7 +41,7 @@ get_predict.default <- function(model,
     # should we try to compute predictions with `insight::get_predicted()`?
     # confidence interval with known `predict` argument
     is_insight <- (!isFALSE(vcov) && !is.na(type_insight)) ||
-                  any(c("include_random", "include_smooth") %in% names(dots))
+        any(c("include_random", "include_smooth") %in% names(dots))
 
     # `insight::get_predicted` yields back-transformed confidence intervals
     if (isTRUE(is_insight)) {
@@ -83,16 +83,27 @@ get_predict.default <- function(model,
 
         args <- c(args, dots)
 
-        f <- insight::get_predicted
-        pred <- try(do.call("f", args), silent = TRUE)
+        fun <- insight::get_predicted
+        pred <- try(do.call("fun", args), silent = TRUE)
 
         # return immediately if this worked
         if (inherits(pred, "get_predicted")) {
             out <- data.frame(pred) # cannot use data.table because insight has no as.data.table method
-            colnames(out)[colnames(out) == "Row"] <- "rowid"
+            if ("rowid" %in% colnames(out)) {
+                out[["Row"]] <- NULL
+            } else {
+                colnames(out)[colnames(out) == "Row"] <- "rowid"
+            }
             colnames(out)[colnames(out) == "Response"] <- "group"
             colnames(out)[colnames(out) == "SE"] <- "std.error"
             colnames(out)[colnames(out) == "Predicted"] <- "predicted"
+            colnames(out)[colnames(out) == "CI_low"] <- "conf.low"
+            colnames(out)[colnames(out) == "CI_high"] <- "conf.high"
+
+            if (nrow(out) == nrow(newdata) && "rowid" %in% colnames(newdata)) {
+                out$rowid <- newdata$rowid
+            }
+
             return(out)
         }
     }
