@@ -74,7 +74,9 @@
 #' compute marginal effects or contrasts. This can differ based on the model
 #' type, but will typically be a string such as: "response", "link", "probs",
 #' or "zero". When an unsupported string is entered, the model-specific list of
-#' acceptable values is returned in an error message.
+#' acceptable values is returned in an error message. When `type` is `NULL`, the
+#' default value is used. This default is the first model-related row in
+#' the `marginaleffects:::type_dictionary` dataframe.
 #' @param slope string indicates the type of slope or (semi-)elasticity to compute:
 #' - "dydx": dY/dX
 #' - "eyex": dY/dX * Y / X
@@ -89,18 +91,21 @@
 #' + String:
 #'   - "pairwise": pairwise differences between estimates in each row.
 #'   - "reference": differences between the estimates in each row and the estimate in the first row.
+#'   - "sequential": difference between an estimate and the estimate in the next row.
+#'   - "revpairwise", "revreference", "revsequential": inverse of the corresponding hypotheses, as described above.
 #' + String formula to specify linear or non-linear hypothesis tests. If the `term` column uniquely identifies rows, terms can be used in the formula. Otherwise, use `b1`, `b2`, etc. to identify the position of each parameter. Examples:
 #'   - `hp = drat`
 #'   - `hp + drat = 12`
 #'   - `b1 + b2 + b3 = 0`
 #' + Numeric vector: Weights to compute a linear combination of (custom contrast between) estimates. Length equal to the number of rows generated by the same function call, but without the `hypothesis` argument.
-#' + Numeric matrix: Each column is a vector of weights, as describe above, used to compute a distinct linear combination of (contrast between) estimates.
+#' + Numeric matrix: Each column is a vector of weights, as describe above, used to compute a distinct linear combination of (contrast between) estimates. The column names of the matrix are used as labels in the output.
 #' + See the Examples section below and the vignette: https://vincentarelbundock.github.io/marginaleffects/articles/hypothesis.html
 #' @param eps NULL or numeric value which determines the step size to use when
 #' calculating numerical derivatives: (f(x+eps)-f(x))/eps. When `eps` is
-#' `NULL`, the step size is step to 0.0001 multiplied by the range of the
-#' variable with respect to which we are taking the derivative. Changing this
-#' value may be necessary to avoid numerical problems in certain models.
+#' `NULL`, the step size is 0.0001 multiplied by the difference between
+#' the maximum and minimum values of the variable with respect to which we
+#' are taking the derivative. Changing `eps` may be necessary to avoid
+#' numerical problems in certain models.
 #' @param ... Additional arguments are passed to the `predict()` method
 #' supplied by the modeling package.These arguments are particularly useful
 #' for mixed-effects or bayesian models (see the online vignettes on the
@@ -185,6 +190,7 @@
 #'     1, -1,
 #'     2, 3),
 #'     ncol = 2)
+#' colnames(lc) <- c("Contrast A", "Contrast B")
 #' marginaleffects(
 #'     mod,
 #'     newdata = "mean",
@@ -196,7 +202,7 @@ marginaleffects <- function(model,
                             variables = NULL,
                             vcov = TRUE,
                             conf_level = 0.95,
-                            type = "response",
+                            type = NULL,
                             slope = "dydx",
                             by = NULL,
                             wts = NULL,
@@ -234,9 +240,9 @@ marginaleffects <- function(model,
     checkmate::assert_choice(slope, choices = valid)
 
     # sanity checks and pre-processing
-    model <- sanitize_model(model = model, newdata = newdata, wts = wts, calling_function = "marginaleffects", ...)
+    model <- sanitize_model(model = model, newdata = newdata, wts = wts, vcov = vcov, calling_function = "marginaleffects", ...)
     sanity_dots(model = model, calling_function = "marginaleffects", ...)
-    sanitize_type(model = model, type = type, calling_function = "marginaleffects")
+    type <- sanitize_type(model = model, type = type, calling_function = "marginaleffects")
 
     out <- comparisons(
         model,
@@ -283,13 +289,12 @@ marginaleffects <- function(model,
         }
     }
 
+    attr(out, "vcov.type") <- get_vcov_label(vcov)
+
     # class
     setDF(out)
     class(out) <- setdiff(class(out), "comparisons")
     class(out) <- c("marginaleffects", class(out))
-
-    attr(out, "vcov.type") <- get_vcov_label(vcov)
-
     return(out)
 }
 
