@@ -1,7 +1,7 @@
 #' @include set_coef.R
 #' @rdname set_coef
 #' @export
-set_coef.betareg <- function(model, coefs) {
+set_coef.betareg <- function(model, coefs, ...) {
     # in betareg, coefficients are a two-element list. We want to substitute the first element!
     # vab: this must absolutely be a named vector, otherwise the precision gets mixed with coefs
     model[["coefficients"]]$mean[names(coefs)] <- coefs
