@@ -1,7 +1,7 @@
 #' @include set_coef.R
 #' @rdname set_coef
 #' @export
-set_coef.glm <- function(model, coefs) {
+set_coef.glm <- function(model, coefs, ...) {
     # in glm coefficients are named vector
     model[["coefficients"]][names(coefs)] <- coefs
     ## But, there's an edge case!! When `predict(model, se.fit = TRUE)` is called without `newdata`, `predict.lm()` isn't called.
@@ -13,7 +13,7 @@ set_coef.glm <- function(model, coefs) {
 
 #' @rdname set_coef
 #' @export
-set_coef.lm <- function(model, coefs) {
+set_coef.lm <- function(model, coefs, ...) {
     # in lm coefficients are named vector
     model[["coefficients"]][names(coefs)] <- coefs
     model
