@@ -13,6 +13,7 @@
 #' @inheritParams plot_cme
 #' @inheritParams predictions
 #' @return A `ggplot2` object
+#' @family plot
 #' @export
 #' @examples
 #' mod <- lm(mpg ~ hp + wt, data = mtcars)
@@ -37,8 +38,6 @@ plot_cap <- function(model,
     dat <- hush(insight::get_data(model))
     resp <- insight::find_response(model)[1]
 
-    checkmate::assert_true(all(condition %in% colnames(dat)))
-
     if (length(condition) == 1) {
         condition1 <- condition[1]
         condition2 <- NULL
@@ -94,6 +93,9 @@ plot_cap <- function(model,
                            conf_level = conf_level,
                            transform_post = transform_post,
                            ...)
+
+    checkmate::assert_true(all(condition %in% colnames(datplot)))
+
     colnames(datplot)[colnames(datplot) == condition1] <- "condition1"
     colnames(datplot)[colnames(datplot) == condition2] <- "condition2"
     colnames(datplot)[colnames(datplot) == condition3] <- "condition3"
@@ -179,5 +181,5 @@ plot_cap <- function(model,
     if (identical(ggplot2::theme_get(), ggplot2::theme_grey())) {
         p <- p + ggplot2::theme_minimal()
     }
-    return(p) 
+    return(p)
 }
