@@ -16,6 +16,7 @@
 #' @inheritParams plot.marginaleffects
 #' @inheritParams marginaleffects
 #' @return A `ggplot2` object
+#' @family plot
 #' @export
 #' @examples
 #' mod <- lm(mpg ~ hp * wt, data = mtcars)
@@ -58,7 +59,6 @@ plot_cco <- function(model,
     checkmate::assert_character(condition, min.len = 1, max.len = 2)
 
     ## not sure why this fails in testthat
-    # checkmate::assert_true(condition %in% colnames(dat))
     if (length(condition) == 1) {
         condition1 <- condition[1]
         condition2 <- NULL
@@ -118,6 +118,9 @@ plot_cco <- function(model,
         interaction = FALSE,
         ...)
 
+
+    checkmate::assert_true(all(condition %in% colnames(datplot)))
+
     draws <- attr(datplot, "posterior_draws")
     colnames(datplot)[colnames(datplot) == condition1] <- "condition1"
     colnames(datplot)[colnames(datplot) == condition2] <- "condition2"
