@@ -29,8 +29,9 @@ sanity_dots <- function(model, calling_function = NULL, ...) {
     valid[["glmmTMB"]] <- c("re.form", "allow.new.levels", "zitype") # glmmTMB
     valid[["bam"]] <- c("exclude") # mgcv
     valid[["rlmerMod"]] <- c("re.form", "allow.new.levels")
+    valid[["gamlss"]] <- c("what", "safe") #gamlss
 
-    white_list <- c("conf.int")
+    white_list <- c("conf.int", "modeldata")
 
     model_class <- class(model)[1]
 
