@@ -13,18 +13,20 @@ sanity_model_specific <- function (model,
 
 #' @rdname sanity_model_specific
 sanity_model_specific.default <- function(model,
+                                          vcov = NULL,
                                           calling_function = "marginaleffects",
                                           ...) {
-    dots <- list(...)
-    # if (length(dots) > 0) {
-    #     warning(sprintf("The following arguments will be ignored: %s. Please refer to the documentation for a list of supported model-specific arguments.", paste(sort(names(dots)), collapse = ", ")))
-    # }
     return(invisible(NULL))
 }
 
 
 sanity_model_supported_class <- function(model) {
-    supported <- list(
+    checkmate::assert_character(
+        getOption("marginaleffects_model_classes", default = NULL),
+        null.ok = TRUE)
+    custom_classes <- getOption("marginaleffects_model_classes", default = NULL)
+    custom_classes <- as.list(custom_classes)
+    supported <- append(custom_classes, list(
         "afex_aov",
         "betareg",
         "bife",
@@ -41,6 +43,7 @@ sanity_model_supported_class <- function(model) {
         "fixest",
         c("Gam", "glm", "lm"), # package: gam
         c("gam", "glm", "lm"), # package: mgcv
+        c("gamlss", "gam", "glm", "lm"), # package: gamlss
         c("geeglm", "gee", "glm"),
         "glm",
         "gls",
@@ -81,7 +84,7 @@ sanity_model_supported_class <- function(model) {
         c("tobit", "survreg"),
         "tobit1",
         "truncreg",
-        "zeroinfl")
+        "zeroinfl"))
     flag <- FALSE
     for (sup in supported) {
         if (!is.null(sup) && isTRUE(all(sup %in% class(model)))) {
@@ -90,20 +93,21 @@ sanity_model_supported_class <- function(model) {
     }
     if (isFALSE(flag)) {
         support <- paste(sort(unique(sapply(supported, function(x) x[1]))), collapse = ", ")
-        msg <-
-'Models of class "%s" are not supported.
-
-Supported model classes include: %s.
-
-New modeling packages can usually be supported by `marginaleffects` if they include a working `predict()` method. If you believe that this is the case, please file a feature request on Github: https://github.com/vincentarelbundock/marginaleffects/issues'
-        msg <- sprintf(msg, class(model)[1], support)
+        msg <- c(
+            sprintf('Models of class "%s" are not supported. Supported model classes include:', class(model)[1]),
+            "",
+            support,
+            "",
+            "New modeling packages can usually be supported by `marginaleffects` if they include a working `predict()` method. If you believe that this is the case, please file a feature request on Github: https://github.com/vincentarelbundock/marginaleffects/issues")
+        msg <- insight::format_message(msg)
         stop(msg, call. = FALSE)
     }
 }
 
 
 sanitize_model <- function(model,
-                           newdata,
+                           newdata = NULL,
+                           vcov = NULL,
                            ...) {
 
     # tidymodels appear to store the model fit in `model[["fit"]]`
@@ -111,7 +115,7 @@ sanitize_model <- function(model,
         model <- model[["fit"]]
     }
 
-    sanity_model_specific(model, newdata = newdata, ...)
+    sanity_model_specific(model, vcov = vcov, newdata = newdata, ...)
     sanity_model_supported_class(model)
     return(model)
 }
