@@ -25,3 +25,24 @@ expect_equivalent(nrow(subset(cmp2, rowid == 1)), 4)
 
 n_unique <- nrow(unique(subset(cmp2, rowid == 1, "contrast")))
 expect_equivalent(n_unique, 4)
+
+
+mod <- lm(mpg ~ hp * drat, mtcars)
+dm <- deltamethod(mod, "`hp:drat` = drat")
+expect_inherits(dm, "deltamethod")
+expect_equivalent(nrow(dm), 1)
+
+
+
+# library(brms)
+# dat <- mtcars
+# dat$gear <- factor(dat$gear)
+# mod <- lm(mpg ~ hp + gear, data = dat)
+# modb <- brm(mpg ~ hp + gear, data = dat)
+
+
+
+# Q
+# pkgload::load_all()
+# marginaleffects(modb, slope = "eyex") |> summary()
+# marginaleffects(mod, slope = "eyex") |> summary()
