@@ -17,7 +17,7 @@ expect_equivalent(mfx$std.error, mfx$std.errorstata, tolerance = .0001)
 stata <- readRDS(testing_path("stata/stata.rds"))$quantreg_rq_01
 model <- quantreg::rq(mpg ~ hp * wt + factor(cyl), data = mtcars)
 mfx <- marginaleffects(model, variables = "hp", newdata = datagrid(hp = 110, wt = 2, cyl = 4))
-em <- emtrends(model, ~hp, "hp", at = list(hp = 110, wt = 2, cyl = 4))
+em <- suppressMessages(emtrends(model, ~hp, "hp", at = list(hp = 110, wt = 2, cyl = 4)))
 em <- tidy(em)
 expect_equivalent(mfx$dydx, em$hp.trend, tolerance = .00001)
 expect_equivalent(mfx$std.error, em$std.error, tolerance = .00001)
