@@ -7,7 +7,7 @@ mod <- lm(mpg ~ gear + cyl + hp, data = tmp)
 
 cmp1 <- comparisons(mod, variables = "hp", newdata = head(tmp, 1))
 expect_equivalent(cmp1$term, "hp")
-expect_equivalent(cmp1$contrast, "(x + 1) - x")
+expect_equivalent(cmp1$contrast, "+1")
 
 cmp2 <- comparisons(mod, variables = list("hp" = 1), newdata = head(tmp, 1))
 expect_equivalent(cmp1, cmp2)
@@ -20,7 +20,7 @@ cmp2 <- comparisons(
     mod,
     variables = list(gear = "sequential", hp = 1, cyl = "pairwise"))
 cmp2 <- tidy(cmp2)
-known <- c("4 - 3", "5 - 4", "(x + 10) - x", "6 - 4", "8 - 4", "8 - 6")
+known <- c("4 - 3", "5 - 4", "+10", "6 - 4", "8 - 4", "8 - 6")
 expect_true(all(known %in% cmp1$contrast))
 expect_equivalent(cmp1$estimate[3], cmp2$estimate[3] * 10)
 
